local mod_name = '__Crawler__'
local vehicle_name = 'crawler'

local icon = mod_name.."/graphics/icons/vehicle.png"
local technology_icon = mod_name.."/graphics/technology/vehicle.png"

data:extend(
{
  {
    type = "car",
    name = vehicle_name,
    icon = icon,
    icon_size = 32,
    flags = {"placeable-neutral", "player-creation", "placeable-off-grid"},
    minable = {mining_time = 1, result = vehicle_name},
    mined_sound = {filename = "__core__/sound/deconstruct-medium.ogg"},
    max_health = 2000,
    corpse = "medium-remnants",
    dying_explosion = "medium-explosion",
    alert_icon_shift = util.by_pixel(-4, -13),
    immune_to_tree_impacts = true,
    energy_per_hit_point = 0.5, -- do nothing?
    resistances =
    {
      {
        type = "fire",
        decrease = 30,
        percent = 90
      },
      {
        type = "physical",
        decrease = 80,
        percent = 20
      },
      {
        type = "impact",
        decrease = 50,
        percent = 80
      },
      {
        type = "explosion",
        decrease = 15,
        percent = 15
      },
      {
        type = "acid",
        decrease = 60,
        percent = 50
      }
    },
    -- collision_box = {{-0.9, -1.3}, {0.9, 1.3}},
    collision_box = {{-0.9, -1.8}, {0.9, 1.8}},
    -- selection_box = {{-0.9, -1.3}, {0.9, 1.3}},
    selection_box = {{-0.9, -1.8}, {0.9, 1.8}},
    -- drawing_box = {{-1.8, -1.8}, {1.8, 1.5}},
    drawing_box = {{-1.8, -2}, {1.8, 2}},
    effectivity = 1,
    braking_power = "600kW",
    burner =
    {
      fuel_category = "chemical",
      effectivity = 1,
      fuel_inventory_size = 3,
    },
    consumption = "1200kW",
    terrain_friction_modifier = 0.2,
    friction = 0.002,
    light =
    {
      {
        type = "oriented",
        minimum_darkness = 0.3,
        picture =
        {
          filename = "__core__/graphics/light-cone.png",
          priority = "extra-high",
          flags = { "light" },
          scale = 2,
          width = 200,
          height = 200
        },
        shift = {-0.6, -14},
        size = 2,
        intensity = 0.6,
        color = {r = 0.9, g = 1.0, b = 1.0}
      },
      {
        type = "oriented",
        minimum_darkness = 0.3,
        picture =
        {
          filename = "__core__/graphics/light-cone.png",
          priority = "extra-high",
          flags = { "light" },
          scale = 2,
          width = 200,
          height = 200
        },
        shift = {0.6, -14},
        size = 2,
        intensity = 0.6,
        color = {r = 0.9, g = 1.0, b = 1.0}
      }
    },
    animation =
    {
      layers =
      {
        {
          filename = mod_name.."/graphics/entity/hr-vehicle.png",

          width = 1464/8,
          height = 1056/8,
          frame_count = 1,
          direction_count = 64,
          line_length = 8,
          shift = util.by_pixel(15, 0),
          animation_speed = 1,
          max_advance = 1,
          priority = "low",
        },
        {
          filename = mod_name.."/graphics/entity/hr-vehicle-mask.png",
          width = 1216/8,
          height = 904/8,
          frame_count = 1,
          direction_count = 64,
          line_length = 8,
          apply_runtime_tint = true,
          shift = util.by_pixel(0, -8),
          max_advance = 1,
          priority = "low",
        }
      }
    },
    stop_trigger_speed = 0.2,
    sound_no_fuel =
    {
      {
        filename = "__base__/sound/fight/tank-no-fuel-1.ogg",
        volume = 0.6
      }
    },
    stop_trigger =
    {
      {
        type = "play-sound",
        sound =
        {
          {
            filename = "__base__/sound/car-breaks.ogg",
            volume = 0.6
          }
        }
      }
    },
    sound_minimum_speed = 0.15;
    vehicle_impact_sound =  { filename = "__base__/sound/car-metal-impact.ogg", volume = 0.65 },
    working_sound =
    {
      sound =
      {
        filename = "__base__/sound/fight/tank-engine.ogg",
        volume = 0.3
      },
      activate_sound =
      {
        filename = "__base__/sound/fight/tank-engine-start.ogg",
        volume = 0.3
      },
      deactivate_sound =
      {
        filename = "__base__/sound/fight/tank-engine-stop.ogg",
        volume = 0.3
      },
      match_speed_to_activity = true
    },
    open_sound = { filename = "__base__/sound/car-door-open.ogg", volume=0.7 },
    close_sound = { filename = "__base__/sound/car-door-close.ogg", volume = 0.7 },
    rotation_speed = 0.007,
    weight = 20000,
    inventory_size = 160,
  },
  
  
  
  {
    type = "item-with-entity-data",
    name = vehicle_name,
    icon = icon,
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "transport",
    order = "b[personal-transport]-b[tank]",
    place_result = vehicle_name,
    stack_size = 1
  },
  
  
  
  {
    type = "recipe",
    name = vehicle_name,

    enabled = false,
    energy_required = 25,
    ingredients =
    {
      {"engine-unit", 50},
      {"steel-plate", 30},
      {"iron-gear-wheel", 10}
    },
    result = vehicle_name
  },

  
  
  {
    type = "technology",
    name = vehicle_name,
    icon = technology_icon,
    icon_size = 128,
    effects =
    {
      {
        type = "unlock-recipe",
        recipe = vehicle_name
      }
    },
    prerequisites = {"automobilism"},
    unit =
    {
      count = 75,
      ingredients =
      {
        {"science-pack-1", 1},
        {"science-pack-2", 1},
        {"science-pack-3", 1}
      },
      time = 30
    },
    order = "e-c-d"
  }
  
})